import { Component, OnInit } from '@angular/core';
import { Router } from '@angular/router';
//import { AlertController, ModalController } from '@ionic/angular';
import { ChatPanelOptions, FmChatModalInput, FmodeChat, FmodeChatMessage, openChatPanelModal } from 'fmode-ng';
import Parse from "parse";
import { CloudObject, CloudQuery } from 'src/lib/ncloud';
import { ModalController } from '@ionic/angular/standalone';  // 统一使用 standalone 路径
interface KnowledgeItem {
  id: string;
  title: string;
  summary: string;
  image: string;
  type: 'article' | 'video';
  category: string;
  tag?: 'emergency' | 'prevention' | 'expert';
  duration?: string;
  isEmergency?: boolean;
}

interface Expert {
  id: string;
  name: string;
  avatar: string;
  specialty: string;
  isOnline: boolean;
  rating: number;
}

@Component({
  selector: 'app-tab2',
  templateUrl: './tab2.page.html',
  styleUrls: ['./tab2.page.scss'],
  standalone: false,
})
export class Tab2Page implements OnInit {




  openConsult(chatId?:string){
    localStorage.setItem("company","E4KpGvTEto")
    let options:ChatPanelOptions = {
      roleId:"2DXJkRsjXK", // 预设，无需更改
      // chatId:chatId, // 若存在，则恢复会话。若不存在，则开启新会话
      onChatInit:(chat:FmodeChat)=>{
        console.log("onChatInit");
        console.log("Chat类",chat);
        console.log("预设角色",chat.role);
        // 角色名称
        chat.role.set("name","林舒窈");
        // 角色称号
        chat.role.set("title","东方食养家");
        // 角色描述
        chat.role.set("desc","谈吐带有中医师的沉稳，擅长用生活化比喻解释复杂理论，林舒窈，年龄26岁");
        // 角色标签
        chat.role.set("tags",['跑步', '动感单车']);
        // 角色头像
        chat.role.set("avatar","/assets/lin.jpg")
        // 角色提示词
        chat.role.set("prompt",`
# 角色设定
姓名：林舒窈（Shuyao Lin）
称号：「东方食养家」
年龄：26岁
背景：

教育：北京中医药大学中医学+营养学双学位，后赴日本进修「药膳料理」，融合传统中医理论与现代营养学。

职业经历：曾任北京某三甲医院临床营养科主任，后创立个人品牌「四季食养」，为明星、企业家定制高端养生膳食。

社会身份：央视《健康中国》栏目常驻嘉宾，著有《本草厨房》《节气餐桌》等畅销书。

形象侧写
外貌：

发型：乌黑及肩中长发，工作时用木簪盘起，干练优雅；

五官：典型的东方温润长相，柳叶眉，眼神柔和但透着专业性的锐利；

着装：工作时穿改良中式立领白袍（袖口绣二十四节气纹样），日常偏爱真丝旗袍+针织开衫。

气质：

谈吐带有中医师的沉稳，擅长用生活化比喻解释复杂理论（如“脾胃就像锅炉，火候不对再好的食材也浪费”）；

手部特写：指甲修剪圆润，无名指戴一枚翡翠戒指（家传药膳秘方的信物）。
`);
        // 对话灵感分类
        let promptCates = [
          {
            "img": "/assets/icon/yy.jpg",
            "name": "营养"
          },
          {
            "img": "/assets/icon/rl.jpg",
            "name": "热量"
          },
          {
            "img": "/assets/icon/aq.jpg",
            "name": "安全"
          }
        ]
        setTimeout(() => {
          chat.role.set("promptCates",promptCates)
        }, 500);
        // 对话灵感列表
        let promptList = [
          {
            cate:"营养",img:"/assets/icon/yy.jpg",
            messageList:[
              "如何在不减少食物种类的情况下保证营养均衡？",
              "有哪些高蛋白但低脂肪的美食推荐？",
              "素食者如何确保摄入足够的蛋白质和铁？",
              "怎样搭配碳水化合物、蛋白质和脂肪的比例更健康？"
            ]
          },
          {
            cate:"热量",img:"/assets/icon/rl.jpg",
            messageList:[
              "有哪些低卡路里但依然美味的零食选择？",
              "如何在享受甜点的同时减少糖分摄入？",
              "外出就餐时如何选择既健康又美味的菜品？",
              "有哪些烹饪方式可以降低食物的热量但保留风味？"
            ]
          },
          {
            cate:"安全",img:"/assets/icon/aq.jpg",
            messageList: [
              "如何判断食材是否新鲜，避免食物中毒？",
              "长期吃外卖如何降低对健康的影响？",
              "有哪些容易被忽视的饮食习惯可能危害健康？",
              "如何合理规划一周的饮食，避免营养单一？"
            ]
          },
        ]
        let ChatPrompt = Parse.Object.extend("ChatPrompt");
        setTimeout(() => {
          chat.promptList = promptList.map(item=>{
            let prompt = new ChatPrompt();
            prompt.set(item);
            prompt.img = item.img;
            return prompt;
          })
        }, 500);

        // 功能按钮区域预设
        chat.leftButtons = [
          { // 提示 当角色配置预设提示词时 显示
           title:"话题灵感", // 按钮标题
           showTitle:true, // 是否显示标题文字
           icon:"color-wand-outline", // 标题icon图标
           onClick:()=>{ // 按钮点击事件
               chat.isPromptModalOpen = true
           },
           show:()=>{ // 按钮显示条件
             return chat?.promptList?.length // 存在话题提示词时显示
           }
         },
      ]

      },
      onMessage:(chat:FmodeChat,message:FmodeChatMessage)=>{
        console.log("onMessage",message)
        let content:any = message?.content
        if(typeof content == "string"){
          // 根据阶段标记判断下一步处理过程
          if (content.includes('[导诊完成]')) {
            // 进入问诊环节
            console.log('进入问诊环节');
          } else if (content.includes('[问诊完成]')) {
            // 进入检查环节
            console.log('进入检查环节');
          } else if (content.includes('[检查完成]')) {
            // 进入诊断与处方环节
            console.log('进入诊断与处方环节');
          } else if (content.includes('[处方完成]')) {
            // 结束会话或其他逻辑
            console.log('结束会话');
          }
        }
      },
      /* onChatSaved 生命周期 保存聊天记录
        会话ID
        聊天内容
        用户的参数 */
      onChatSaved:async (chat:FmodeChat)=>{
        // chat?.chatSession?.id 本次会话的 chatId
        console.log("onChatSaved",chat,chat?.chatSession,chat?.chatSession?.id)
        let chatId = chat?.chatSession?.id;
        console.log("chatId",chatId);
        let query = new CloudQuery("NutritionConsult");
        let nutritionConsult = await query.get(chatId);
        console.log("nutritionConsult",nutritionConsult)
        //若无重复记录，则实例化一个新的咨询记录
        if(!nutritionConsult?.id){
         nutritionConsult = new CloudObject("NutritionConsult"); 
        }
        nutritionConsult.set({
          "chatId":chatId,
          "messageList":chat.messageList,
          "name" :chat.role.get("name"),
          "avatar":chat.role.get("avatar"),
        });

        console.log("nutritionConsult",nutritionConsult);
        nutritionConsult.save();
      }
    }
    openChatPanelModal(this.modalCtrl,options)
  }
  consultList:Array<CloudObject> = [];






  searchQuery = '';
  isLargeFont = false;
  currentCategory = 'all';

  categories = [
    { id: 'all', name: '全部', icon: 'apps' },
    { id: 'wheat', name: '小麦', icon: 'leaf' },
    { id: 'rice', name: '水稻', icon: 'water' },
    { id: 'corn', name: '玉米', icon: 'ear' },
    { id: 'fruit', name: '果树', icon: 'nutrition' },
  ];

  onlineExperts: Expert[] = [
    {
      id: '1',
      name: '张农艺师',
      avatar: 'assets/images/expert1.jpg',
      specialty: '水稻种植专家',
      isOnline: true,
      rating: 4.8
    },
    {
      id: '2',
      name: '李研究员',
      avatar: 'assets/images/expert2.jpg',
      specialty: '果树病虫害防治',
      isOnline: true,
      rating: 4.9
    },
    {
      id: '3',
      name: '王技术员',
      avatar: 'assets/images/expert3.jpg',
      specialty: '土壤改良',
      isOnline: true,
      rating: 4.7
    }
  ];

  knowledgeList: KnowledgeItem[] = [
    {
      id: '1',
      title: '小麦赤霉病防治',
      summary: '识别赤霉病早期症状及防治方案',
      image: 'assets/images/wheat-disease.jpg',
      type: 'article',
      category: 'wheat',
      tag: 'emergency',
      isEmergency: true
    },
    {
      id: '2',
      title: '水稻科学灌溉技巧',
      summary: '不同生长阶段的水分管理要点',
      image: 'assets/images/rice-irrigation.jpg',
      type: 'article',
      category: 'rice',
      tag: 'expert',
      duration: '5分钟阅读'
    },
    {
      id: '3',
      title: '果树修剪实操指南',
      summary: '视频演示冬季修剪的正确方法',
      image: 'assets/images/fruit-pruning.jpg',
      type: 'video',
      category: 'fruit',
      duration: '12分钟'
    },
    {
      id: '4',
      title: '玉米螟虫预防措施',
      summary: '生物防治与化学防治结合方案',
      image: 'assets/images/corn-pest.jpg',
      type: 'article',
      category: 'corn',
      tag: 'prevention'
    },
    {
      id: '5',
      title: '土壤改良方法',
      summary: '酸性土壤改良的7种有效方式',
      image: 'assets/images/soil-improve.jpg',
      type: 'article',
      category: 'all',
      duration: '8分钟阅读'
    }
  ];

  filteredKnowledge: KnowledgeItem[] = [];

  constructor(
    private modalCtrl:ModalController,
    private router: Router,
    //private alertCtrl: AlertController
  ) {}

  ngOnInit() {
    this.filteredKnowledge = [...this.knowledgeList];
  }

  toggleFontSize() {
    this.isLargeFont = !this.isLargeFont;
  }

  refreshData() {
    // 模拟刷新数据
    this.filteredKnowledge = [...this.knowledgeList];
    this.searchQuery = '';
    this.currentCategory = 'all';
  }

  resetFilters() {
    this.refreshData();
  }

  onSearch() {
    if (!this.searchQuery) {
      this.filteredKnowledge = [...this.knowledgeList];
      return;
    }

    const query = this.searchQuery.toLowerCase();
    this.filteredKnowledge = this.knowledgeList.filter(item => 
      item.title.toLowerCase().includes(query) || 
      item.summary.toLowerCase().includes(query)
    );
  }

  startVoiceSearch() {
    console.log('启动语音搜索');
    // 实际应集成语音识别API
  }

  filterByCategory() {
    if (this.currentCategory === 'all') {
      this.filteredKnowledge = [...this.knowledgeList];
    } else {
      this.filteredKnowledge = this.knowledgeList.filter(
        item => item.category === this.currentCategory
      );
    }
  }

  navigateToDetail(item: KnowledgeItem) {
    this.router.navigate(['/knowledge-detail', item.id]);
  }

  getTagColor(tag: string): string {
    switch (tag) {
      case 'emergency': return 'danger';
      case 'prevention': return 'warning';
      case 'expert': return 'success';
      default: return 'primary';
    }
  }

  getTagLabel(tag: string): string {
    switch (tag) {
      case 'emergency': return '紧急';
      case 'prevention': return '预防';
      case 'expert': return '专家推荐';
      default: return '';
    }
  }
}